#[non_exhaustive]pub enum ProjectionIssue {
MissingRequiredField {
field: &'static str,
},
MissingRequiredFields {
fields: Vec<&'static str>,
},
InvalidField {
field: &'static str,
details: String,
},
ConversionFailed {
target: &'static str,
},
CurrencyUnresolved,
InvalidCurrency {
code: String,
},
ProviderError {
message: String,
},
ProviderUnavailable {
feature: &'static str,
},
}Expand description
Why provider data could not be represented losslessly.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingRequiredField
A required provider field was absent or null.
MissingRequiredFields
One or more required provider fields were absent or null.
InvalidField
A provider field was present but malformed.
ConversionFailed
A present value could not be represented by the target public type.
CurrencyUnresolved
A monetary value was present, but no currency could be resolved.
InvalidCurrency
A provider currency code was present but invalid.
ProviderError
Yahoo returned an API or provider-level error.
Yahoo did not return a requested module or feature.