Interval

Enum Interval 

#[non_exhaustive]
pub enum Interval {
Show 35 variants I1s, I2s, I3s, I5s, I6s, I10s, I15s, I30s, I90s, I1m, I2m, I3m, I5m, I6m, I10m, I15m, I30m, I90m, I1h, I2h, I3h, I4h, I6h, I8h, I12h, D1, D5, W1, M1, M3, M6, Y1, Y2, Y5, Y10,
}
Supported resolution intervals.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


I1s

1 second



I2s

2 seconds



I3s

3 seconds



I5s

5 seconds



I6s

6 seconds



I10s

10 seconds



I15s

15 seconds



I30s

30 seconds



I90s

90 seconds



I1m

1 minute



I2m

2 minutes



I3m

3 minutes



I5m

5 minutes



I6m

6 minutes



I10m

10 minutes



I15m

15 minutes



I30m

30 minutes



I90m

90 minutes



I1h

1 hour



I2h

2 hours



I3h

3 hours



I4h

4 hours



I6h

6 hours



I8h

8 hours



I12h

12 hours



D1

1 day



D5

5 days (provider-dependent)



W1

1 week



M1

1 month



M3

3 months



M6

6 months



Y1

1 year



Y2

2 years



Y5

5 years



Y10

10 years

Implementations

Source

impl Interval

pub const fn code(self) -> &'static str

Returns the stable wire-format code for this interval.

pub const fn is_intraday(self) -> bool

Is this an intraday interval?

pub const fn minutes(self) -> Option<i64>

Returns the interval length in minutes for intraday, otherwise None.

pub const fn seconds(self) -> Option<i64>

Returns the interval length in seconds for intraday, otherwise None.