Profile

Enum Profile 

#[non_exhaustive]
pub enum Profile { Company(CompanyProfile), Fund(FundProfile), }
Union of supported profile kinds.

Serde uses a flat tagged shape with a kind discriminator. Fund profiles use fund_kind on the wire to avoid colliding with the discriminator. This is a tagged data payload, not a strict semantic metadata shape: deserialization intentionally ignores unmodeled provider fields.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Company(CompanyProfile)

Company profile.



Fund(FundProfile)

Fund profile.

Implementations

Source

impl Profile

pub const fn isin(&self) -> Option<&Isin>

Returns the ISIN for the company or fund, if available.