pub struct NetSharePurchaseActivity {
pub period: ReportingPeriod,
pub buy_shares: Option<u64>,
pub buy_count: Option<u64>,
pub sell_shares: Option<u64>,
pub sell_count: Option<u64>,
pub net_shares: Option<i64>,
pub net_count: Option<i64>,
pub total_insider_shares: Option<u64>,
pub net_percent_insider_shares: Option<Decimal>,
}Expand description
A summary of net share purchase activity by insiders over a specific period.
Fields
period: ReportingPeriodThe period the summary covers (e.g., ReportingPeriod::quarterly(2023, 4)?).
The total number of shares purchased by insiders.
buy_count: Option<u64>The number of separate buy transactions.
The total number of shares sold by insiders.
sell_count: Option<u64>The number of separate sell transactions.
The net number of shares purchased or sold.
net_count: Option<i64>The net number of transactions.
The total number of shares held by all insiders.
The net shares purchased/sold as a percentage of total insider shares.